# Installation

The instructions below will help you to properly install the generated package to the lavalite project.

## Location

Extract the package contents to the folder 

`/packages/classifieds/chat/`

## Composer

Add the below entries in the `composer.json` file's autoload section and run the command `composer dump-autoload` in terminal.

```json

...
     "autoload": {
         ...

        "classmap": [
            ...
            
            "packages/classifieds/chat/database/seeds",
            
            ...
        ],
        "psr-4": {
            ...
            
            "Classifieds\\Chat\\": "packages/classifieds/chat/src",
            
            ...
        }
    },
...

```

## Config

Add the entries in service provider in `config/app.php`

```php

...
    'providers'       => [
        ...
        
        Classifieds\Chat\Providers\ChatServiceProvider::class,
        
        ...
    ],

    ...

    'alias'             => [
        ...
        
        'Chat'  => Classifieds\Chat\Facades\Chat::class,
        
        ...
    ]
...

```

## Migrate

After service provider is set run the commapnd to migrate and seed the database.


    php artisan migrate
    php artisan db:seed --class=Classifieds\\ChatTableSeeder

## Publishing


**Publishing configuration**

    php artisan vendor:publish --provider="Classifieds\Chat\Providers\ChatServiceProvider" --tag="config"

**Publishing language**

    php artisan vendor:publish --provider="Classifieds\Chat\Providers\ChatServiceProvider" --tag="lang"

**Publishing views**

    php artisan vendor:publish --provider="Classifieds\Chat\Providers\ChatServiceProvider" --tag="view"


## URLs and APIs


### Web Urls

**Admin**

    http://path-to-route-folder/admin/chat/{modulename}

**User**

    http://path-to-route-folder/user/chat/{modulename}

**Public**

    http://path-to-route-folder/chats


### API endpoints

**List**
 
    http://path-to-route-folder/api/user/chat/{modulename}
    METHOD: GET

**Create**

    http://path-to-route-folder/api/user/chat/{modulename}
    METHOD: POST

**Edit**

    http://path-to-route-folder/api/user/chat/{modulename}/{id}
    METHOD: PUT

**Delete**

    http://path-to-route-folder/api/user/chat/{modulename}/{id}
    METHOD: DELETE

**Public List**

    http://path-to-route-folder/api/chat/{modulename}
    METHOD: GET

**Public Single**

    http://path-to-route-folder/api/chat/{modulename}/{slug}
    METHOD: GET