<?php

namespace Classifieds\Chat\Http\Controllers;

use App\Http\Controllers\APIController as BaseController;
use Classifieds\Chat\Http\Requests\ChatRequest;
use Classifieds\Chat\Interfaces\ChatRepositoryInterface;
use Classifieds\Chat\Models\Chat;
use Classifieds\Chat\Forms\Chat as Form;

/**
 * APIController  class for chat.
 */
class ChatAPIController extends BaseController
{

    /**
     * Initialize chat resource controller.
     *
     * @param type ChatRepositoryInterface $chat
     *
     * @return null
     */
    public function __construct(ChatRepositoryInterface $chat)
    {
        parent::__construct();
        $this->repository = $chat;
        $this->repository
            ->pushCriteria(\Litepie\Repository\Criteria\RequestCriteria::class)
            ->pushCriteria(\Classifieds\Chat\Repositories\Criteria\ChatResourceCriteria::class);
    }

    /**
     * Display a list of chat.
     *
     * @return Response
     */
    public function index(ChatRequest $request)
    {
        return $this->repository
            ->setPresenter(\Classifieds\Chat\Repositories\Presenter\ChatPresenter::class)
            ->paginate();
    }

    /**
     * Display chat.
     *
     * @param Request $request
     * @param Model   $chat
     *
     * @return Response
     */
    public function show(ChatRequest $request, Chat $chat)
    {
        return $chat->setPresenter(\Classifieds\Chat\Repositories\Presenter\ChatListPresenter::class);
        ;
    }

    /**
     * Create new chat.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function store(ChatRequest $request)
    {
        try {
            $data              = $request->all();
            $data['user_id']   = user_id();
            $data['user_type'] = user_type();
            $data              = $this->repository->create($data);
            $message           = trans('messages.success.created', ['Module' => trans('chat::chat.name')]);
            $code              = 204;
            $status            = 'success';
            $url               = guard_url('chat/chat/' . $chat->getRouteKey());
        } catch (Exception $e) {
            $message = $e->getMessage();
            $code    = 400;
            $status  = 'error';
            $url     = guard_url('chat/chat');
        }
        return compact('data', 'message', 'code', 'status', 'url');
    }

    /**
     * Update the chat.
     *
     * @param Request $request
     * @param Model   $chat
     *
     * @return Response
     */
    public function update(ChatRequest $request, Chat $chat)
    {
        try {
            $data = $request->all();

            $chat->update($data);
            $message = trans('messages.success.updated', ['Module' => trans('chat::chat.name')]);
            $code    = 204;
            $status  = 'success';
            $url     = guard_url('chat/chat/' . $chat->getRouteKey());
        } catch (Exception $e) {
            $message = $e->getMessage();
            $code    = 400;
            $status  = 'error';
            $url     = guard_url('chat/chat/' . $chat->getRouteKey());
        }
        return compact('data', 'message', 'code', 'status', 'url');
    }

    /**
     * Remove the chat.
     *
     * @param Model   $chat
     *
     * @return Response
     */
    public function destroy(ChatRequest $request, Chat $chat)
    {
        try {
            $chat->delete();
            $message = trans('messages.success.deleted', ['Module' => trans('chat::chat.name')]);
            $code    = 202;
            $status  = 'success';
            $url     = guard_url('chat/chat/0');
        } catch (Exception $e) {
            $message = $e->getMessage();
            $code    = 400;
            $status  = 'error';
            $url     = guard_url('chat/chat/' . $chat->getRouteKey());
        }
        return compact('message', 'code', 'status', 'url');
    }

    /**
     * Return the form elements as json.
     *
     * @param String   $element
     *
     * @return json
     */
    public function form($element = 'fields')
    {
        $form = new Form();
        return $form->form($element, true);
    }

}
