<?php

namespace Classifieds\Chat\Policies;

use Litepie\User\Contracts\UserPolicy;
use Classifieds\Chat\Models\Chat;

class ChatPolicy
{

    /**
     * Determine if the given user can view the chat.
     *
     * @param UserPolicy $user
     * @param Chat $chat
     *
     * @return bool
     */
    public function view(UserPolicy $user, Chat $chat)
    {
        if ($user->canDo('chat.chat.view') && $user->isAdmin()) {
            return true;
        }

        return $chat->user_id == user_id() && $chat->user_type == user_type();
    }

    /**
     * Determine if the given user can create a chat.
     *
     * @param UserPolicy $user
     * @param Chat $chat
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('chat.chat.create');
    }

    /**
     * Determine if the given user can update the given chat.
     *
     * @param UserPolicy $user
     * @param Chat $chat
     *
     * @return bool
     */
    public function update(UserPolicy $user, Chat $chat)
    {
        if ($user->canDo('chat.chat.edit') && $user->isAdmin()) {
            return true;
        }

        return $chat->user_id == user_id() && $chat->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given chat.
     *
     * @param UserPolicy $user
     * @param Chat $chat
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, Chat $chat)
    {
        return $chat->user_id == user_id() && $chat->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given chat.
     *
     * @param UserPolicy $user
     * @param Chat $chat
     *
     * @return bool
     */
    public function verify(UserPolicy $user, Chat $chat)
    {
        if ($user->canDo('chat.chat.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given chat.
     *
     * @param UserPolicy $user
     * @param Chat $chat
     *
     * @return bool
     */
    public function approve(UserPolicy $user, Chat $chat)
    {
        if ($user->canDo('chat.chat.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
